@@ -1,13 +1,17 @@
 try:
-    import nutOther as oth
+    from pynut_1tools.pyNutTools import nutOther as oth
 except:
-    print('Online Test...')
-    from pyNutTools import nutOther as oth
+    try:
+        from pyNutTools import nutOther as oth
+    except:
+        print('Online Test...')
+        from pyNut import nutOther as oth
+
 from time import sleep
 # import pytest
 
 
-# pytest test/test_nutOther.py
+# python -m pytest test/test_nutOther.py
 
 
 #=============================================================================
